@@ -37,8 +37,7 @@ from .extensions import CameraSkybellControllerExtension
 from .extensions import ConfigurationOption
 from .extensions import ExtendedProperties
 
-__version__ = "0.4.5"
-
+__version__ = "0.4.7"
 
 log = logging.getLogger(__name__)
 
@@ -98,8 +97,6 @@ class AlarmController:
     LOGIN_2FA_REQUEST_OTP_SMS_URL_TEMPLATE = "{}web/api/twoFactorAuthentication/twoFactorAuthentications/{}/sendTwoFactorAuthenticationCode"
     LOGIN_2FA_REQUEST_OTP_EMAIL_URL_TEMPLATE = "{}web/api/twoFactorAuthentication/twoFactorAuthentications/{}/sendTwoFactorAuthenticationCodeViaEmail"
 
-    IDENTITIES_2FA_NAG_URL_TEMPLATE = "{}system-install/api/identity"
-
     VIEWSTATE_FIELD = "__VIEWSTATE"
     VIEWSTATEGENERATOR_FIELD = "__VIEWSTATEGENERATOR"
     EVENTVALIDATION_FIELD = "__EVENTVALIDATION"
@@ -390,7 +387,7 @@ class AlarmController:
                 and (msg_body.get("forceBypass") is True)
             ):
                 # 422 sometimes occurs when forceBypass is True but there's nothing to bypass.
-                log.warning(
+                log.debug(
                     "Error executing %s, trying again without force bypass...",
                     event.value,
                 )
@@ -563,7 +560,7 @@ class AlarmController:
                 # Indicates fatal account error.
                 raise PermissionError from err
 
-            except DataFetchFailed as err:
+            except DataFetchFailed:
                 log.error(
                     "Encountered data error while fetching %ss. Skipping this device"
                     " type.",
@@ -872,7 +869,10 @@ class AlarmController:
 
     # Takes EITHER url (without base) or device_type.
     async def _async_get_items_and_subordinates(
-        self, device_type: DeviceType | None = None, url: str | None = None
+        self,
+        device_type: DeviceType | None = None,
+        url: str | None = None,
+        retry_on_failure: bool = True,
     ) -> list:
         """Get attributes, metadata, and child devices for an ADC device class."""
 
@@ -936,14 +936,28 @@ class AlarmController:
                 # All requests for those device types will return 403.
                 #
                 # On some providers, 403 may mean that the user has been logged out.
-                # For now, we'll ignore this case.
+                # Try logging in again, then give up by pretending that we couldn't find any devices of this type.
 
-                log.debug(
-                    "Got 403 status when fetching data for device type %s.", device_type
+                log.error("Error fetching data from Alarm.com.")
+
+                if not retry_on_failure:
+                    log.debug(
+                        "Got 403 status when fetching data for device type %s. Logging"
+                        " in again didn't help.",
+                        device_type,
+                    )
+
+                    return list([])
+
+                log.error("Trying to refresh auth tokens by logging in again.")
+
+                await self.async_login()
+
+                return await self._async_get_items_and_subordinates(
+                    device_type=device_type,
+                    retry_on_failure=False,
                 )
 
-                return list([])
-
             if (
                 rsp_errors[0].get("status") == "409"
                 and rsp_errors[0].get("detail") == "TwoFactorAuthenticationRequired"
@@ -1063,7 +1077,10 @@ class AlarmController:
                     raise AuthenticationFailed("Invalid username and password.")
 
                 # If Alarm.com is warning us that we'll have to set up two factor authentication soon, alert caller.
-                if re.search("system-install", str(resp.url)) is not None:
+                if (
+                    re.search("concurrent-two-factor-authentication", str(resp.url))
+                    is not None
+                ):
                     raise NagScreen("Encountered 2FA nag screen.")
 
                 self._ajax_headers["ajaxrequestuniquekey"] = resp.cookies["afg"].value
