@@ -106,7 +106,7 @@ class CameraSkybellControllerExtension(ControllerExtension):
 
     _description = "Adjust indoor and outdoor chimes for Skybell HD video doorbells."
 
-    class ChimeAdjustableVolume(ExtendedEnumMixin, Enum):
+    class ChimeAdjustableVolume(ExtendedEnumMixin):
         """Doorbell chime levels for bells with configurable volume."""
 
         OFF = 0
@@ -114,13 +114,13 @@ class CameraSkybellControllerExtension(ControllerExtension):
         MEDIUM = 2
         HIGH = 3
 
-    class ChimeOnOff(ExtendedEnumMixin, Enum):
+    class ChimeOnOff(ExtendedEnumMixin):
         """Doorbell chime levels for bells with configurable volume."""
 
         OFF = "off"
         ON = "on"
 
-    class MotionSensitivity(ExtendedEnumMixin, Enum):
+    class MotionSensitivity(ExtendedEnumMixin):
         """Camera motion sensor sensitivity."""
 
         LOW = 1
@@ -286,7 +286,6 @@ class CameraSkybellControllerExtension(ControllerExtension):
                 ).findChildren():
                     camera_config_id: str = child.attrs.get("value")
                     if child.attrs.get("selected") == "selected":
-
                         # Retrieve data for camera on current page.
                         current_form_data = self._extract_fields(camera_config_id, tree)
 
@@ -380,7 +379,6 @@ class CameraSkybellControllerExtension(ControllerExtension):
         field_config_options: ConfigurationOption
 
         try:
-
             for config_option_field_name, config_option in self._form_field_settings:
                 if config_option.slug == slug:
                     field_name = config_option_field_name
@@ -554,7 +552,7 @@ class CameraSkybellControllerExtension(ControllerExtension):
     def _build_submit_payload(  # pylint: disable = no-self-use
         self, response_data: dict
     ) -> dict:
-        """Build POST body for submitting settings changes or for getting data for a different camera."""
+        """Build POST for new setting submission or for getting other camera data."""
 
         # Pre-populate static fields.
         static_form_data: dict = {
@@ -583,6 +581,8 @@ class CameraSkybellControllerExtension(ControllerExtension):
     ) -> ExtendedProperties:
         """Extract data from camera config page."""
 
+        # To prevent a single Skybell error from throwing an exception, missing fields will have values set to empty strings.
+
         raw_attribs: dict = {}
         properties = ExtendedProperties(
             config_id=config_id,
@@ -590,35 +590,46 @@ class CameraSkybellControllerExtension(ControllerExtension):
         )
 
         try:
-
             for field_name in self._FORM_FIELDS_BYPASSABLE:
-
                 field = tree.find(attrs={"name": field_name})
 
                 if not field:
                     raw_attribs[field_name] = ""
                 else:
-                    value = extract_field_value(field)
+                    try:
+                        value = extract_field_value(field)
+                    except UnexpectedDataStructure:
+                        log.warning("Couldn't find field %s", field)
+                        value = ""
                     raw_attribs[field_name] = value
 
             for field_name in self._FORM_FIELDS_GENERIC:
-
                 field = tree.find(attrs={"name": field_name})
-                value = extract_field_value(field)
+                try:
+                    value = extract_field_value(field)
+                except UnexpectedDataStructure:
+                    log.warning("Couldn't find field %s", field)
+                    value = ""
                 raw_attribs[field_name] = value
 
             for field_name, property_name in self._FORM_FIELDS_META:
-
                 field = tree.find(attrs={"name": field_name})
-                value = extract_field_value(field)
+                try:
+                    value = extract_field_value(field)
+                except UnexpectedDataStructure:
+                    log.warning("Couldn't find field %s", field)
+                    value = ""
                 raw_attribs[field_name] = value
                 setattr(properties, property_name, value)
 
             for field_name, config_option in self._form_field_settings:
-
                 field = tree.find(attrs={"name": field_name})
 
-                value = extract_field_value(field)
+                try:
+                    value = extract_field_value(field)
+                except UnexpectedDataStructure:
+                    log.warning("Couldn't find field %s", field)
+                    value = ""
 
                 typed_value: Any
 
@@ -635,7 +646,6 @@ class CameraSkybellControllerExtension(ControllerExtension):
                 # Conversions for ChimeOnOff values.
 
                 if config_value_type == self.ChimeOnOff:
-
                     typed_value = self.ChimeOnOff.ON if value else self.ChimeOnOff.OFF
 
                     raw_attribs[field_name] = typed_value.value
@@ -662,7 +672,6 @@ class CameraSkybellControllerExtension(ControllerExtension):
                 if config_option_type == ConfigurationOptionType.COLOR and (
                     value_regex := config_option.value_regex
                 ):
-
                     if not value:
                         raise ValueError
 
@@ -677,7 +686,6 @@ class CameraSkybellControllerExtension(ControllerExtension):
                 # Ints
 
                 if config_value_type == int:
-
                     if not value:
                         raise ValueError
 
